# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class CustomerError(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_field_errors': 'list[str]',
        'id': 'list[str]',
        'stripe_id': 'list[str]',
        'created': 'list[str]',
        'metadata': 'list[str]',
        'livemode': 'list[str]',
        'account_balance': 'list[str]',
        'currency': 'list[str]',
        'last_invoice_sync': 'list[str]',
        'user': 'list[str]',
        'default_source': 'list[str]'
    }

    attribute_map = {
        'non_field_errors': 'non_field_errors',
        'id': 'id',
        'stripe_id': 'stripe_id',
        'created': 'created',
        'metadata': 'metadata',
        'livemode': 'livemode',
        'account_balance': 'account_balance',
        'currency': 'currency',
        'last_invoice_sync': 'last_invoice_sync',
        'user': 'user',
        'default_source': 'default_source'
    }

    def __init__(self, non_field_errors=None, id=None, stripe_id=None, created=None, metadata=None, livemode=None, account_balance=None, currency=None, last_invoice_sync=None, user=None, default_source=None):
        """
        CustomerError - a model defined in Swagger
        """

        self._non_field_errors = None
        self._id = None
        self._stripe_id = None
        self._created = None
        self._metadata = None
        self._livemode = None
        self._account_balance = None
        self._currency = None
        self._last_invoice_sync = None
        self._user = None
        self._default_source = None

        if non_field_errors is not None:
          self.non_field_errors = non_field_errors
        if id is not None:
          self.id = id
        if stripe_id is not None:
          self.stripe_id = stripe_id
        if created is not None:
          self.created = created
        if metadata is not None:
          self.metadata = metadata
        if livemode is not None:
          self.livemode = livemode
        if account_balance is not None:
          self.account_balance = account_balance
        if currency is not None:
          self.currency = currency
        if last_invoice_sync is not None:
          self.last_invoice_sync = last_invoice_sync
        if user is not None:
          self.user = user
        if default_source is not None:
          self.default_source = default_source

    @property
    def non_field_errors(self):
        """
        Gets the non_field_errors of this CustomerError.
        Errors not connected to any field

        :return: The non_field_errors of this CustomerError.
        :rtype: list[str]
        """
        return self._non_field_errors

    @non_field_errors.setter
    def non_field_errors(self, non_field_errors):
        """
        Sets the non_field_errors of this CustomerError.
        Errors not connected to any field

        :param non_field_errors: The non_field_errors of this CustomerError.
        :type: list[str]
        """

        self._non_field_errors = non_field_errors

    @property
    def id(self):
        """
        Gets the id of this CustomerError.
        id field errors

        :return: The id of this CustomerError.
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CustomerError.
        id field errors

        :param id: The id of this CustomerError.
        :type: list[str]
        """

        self._id = id

    @property
    def stripe_id(self):
        """
        Gets the stripe_id of this CustomerError.
        stripe_id field errors

        :return: The stripe_id of this CustomerError.
        :rtype: list[str]
        """
        return self._stripe_id

    @stripe_id.setter
    def stripe_id(self, stripe_id):
        """
        Sets the stripe_id of this CustomerError.
        stripe_id field errors

        :param stripe_id: The stripe_id of this CustomerError.
        :type: list[str]
        """

        self._stripe_id = stripe_id

    @property
    def created(self):
        """
        Gets the created of this CustomerError.
        created field errors

        :return: The created of this CustomerError.
        :rtype: list[str]
        """
        return self._created

    @created.setter
    def created(self, created):
        """
        Sets the created of this CustomerError.
        created field errors

        :param created: The created of this CustomerError.
        :type: list[str]
        """

        self._created = created

    @property
    def metadata(self):
        """
        Gets the metadata of this CustomerError.
        metadata field errors

        :return: The metadata of this CustomerError.
        :rtype: list[str]
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this CustomerError.
        metadata field errors

        :param metadata: The metadata of this CustomerError.
        :type: list[str]
        """

        self._metadata = metadata

    @property
    def livemode(self):
        """
        Gets the livemode of this CustomerError.
        livemode field errors

        :return: The livemode of this CustomerError.
        :rtype: list[str]
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """
        Sets the livemode of this CustomerError.
        livemode field errors

        :param livemode: The livemode of this CustomerError.
        :type: list[str]
        """

        self._livemode = livemode

    @property
    def account_balance(self):
        """
        Gets the account_balance of this CustomerError.
        account_balance field errors

        :return: The account_balance of this CustomerError.
        :rtype: list[str]
        """
        return self._account_balance

    @account_balance.setter
    def account_balance(self, account_balance):
        """
        Sets the account_balance of this CustomerError.
        account_balance field errors

        :param account_balance: The account_balance of this CustomerError.
        :type: list[str]
        """

        self._account_balance = account_balance

    @property
    def currency(self):
        """
        Gets the currency of this CustomerError.
        currency field errors

        :return: The currency of this CustomerError.
        :rtype: list[str]
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this CustomerError.
        currency field errors

        :param currency: The currency of this CustomerError.
        :type: list[str]
        """

        self._currency = currency

    @property
    def last_invoice_sync(self):
        """
        Gets the last_invoice_sync of this CustomerError.
        last_invoice_sync field errors

        :return: The last_invoice_sync of this CustomerError.
        :rtype: list[str]
        """
        return self._last_invoice_sync

    @last_invoice_sync.setter
    def last_invoice_sync(self, last_invoice_sync):
        """
        Sets the last_invoice_sync of this CustomerError.
        last_invoice_sync field errors

        :param last_invoice_sync: The last_invoice_sync of this CustomerError.
        :type: list[str]
        """

        self._last_invoice_sync = last_invoice_sync

    @property
    def user(self):
        """
        Gets the user of this CustomerError.
        user field errors

        :return: The user of this CustomerError.
        :rtype: list[str]
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this CustomerError.
        user field errors

        :param user: The user of this CustomerError.
        :type: list[str]
        """

        self._user = user

    @property
    def default_source(self):
        """
        Gets the default_source of this CustomerError.
        default_source field errors

        :return: The default_source of this CustomerError.
        :rtype: list[str]
        """
        return self._default_source

    @default_source.setter
    def default_source(self, default_source):
        """
        Sets the default_source of this CustomerError.
        default_source field errors

        :param default_source: The default_source of this CustomerError.
        :type: list[str]
        """

        self._default_source = default_source

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, CustomerError):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
