# coding: utf-8

"""
    3blades API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class NotificationListUpdateData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'notifications': 'list[str]',
        'read': 'bool'
    }

    attribute_map = {
        'notifications': 'notifications',
        'read': 'read'
    }

    def __init__(self, notifications=None, read=None):
        """
        NotificationListUpdateData - a model defined in Swagger
        """

        self._notifications = None
        self._read = None

        self.notifications = notifications
        self.read = read

    @property
    def notifications(self):
        """
        Gets the notifications of this NotificationListUpdateData.
        An array of notification IDs to update.

        :return: The notifications of this NotificationListUpdateData.
        :rtype: list[str]
        """
        return self._notifications

    @notifications.setter
    def notifications(self, notifications):
        """
        Sets the notifications of this NotificationListUpdateData.
        An array of notification IDs to update.

        :param notifications: The notifications of this NotificationListUpdateData.
        :type: list[str]
        """
        if notifications is None:
            raise ValueError("Invalid value for `notifications`, must not be `None`")

        self._notifications = notifications

    @property
    def read(self):
        """
        Gets the read of this NotificationListUpdateData.
        Mark the notification as either read or unread

        :return: The read of this NotificationListUpdateData.
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """
        Sets the read of this NotificationListUpdateData.
        Mark the notification as either read or unread

        :param read: The read of this NotificationListUpdateData.
        :type: bool
        """
        if read is None:
            raise ValueError("Invalid value for `read`, must not be `None`")

        self._read = read

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, NotificationListUpdateData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
